@@ -164,29 +164,19 @@ def build_parser():
         '--alltags',
         nargs='*',
         default=[
-            "ubuntu_trusty",
-            "ubuntu_xenial",
-            "ubuntu_bionic",
-            "fedora_23",
-            "fedora_24",
-            "fedora_25",
-            "fedora_26",
-            "fedora_27",
-            "fedora_28",
-            "fedora_29",
-            "fedora_30",
-            "centos_7",
-            "alpine_3.3",
-            "alpine_3.4",
-            "alpine_3.5",
-            "alpine_3.6",
-            "alpine_3.7",
-            "alpine_3.8",
-            "alpine_3.9",
+            "alpine_3.14",
+            "alpine_3.15",
             "alpine_edge",
             "archlinux_latest",
-            "debian_jessie",
-            "debian_stretch",
+            "centos_8",
+            "debian_bullseye",
+            "debian_buster",
+            "fedora_34",
+            "fedora_35",
+            "rockylinux_8.4",
+            "rockylinux_8.5",
+            "ubuntu_bionic",
+            "ubuntu_focal",
         ],
         help='set of all platforms for the --{write,pull,build}all options'
     )
